@@ -3,8 +3,6 @@ import unittest
 import pandas as pd
 import numpy as np
 
-from sklearn.metrics import r2_score, roc_auc_score
-
 import shap
 import plotly.graph_objects as go
 
@@ -25,7 +23,7 @@ class LinearRegressionTests(unittest.TestCase):
 
         model = LinearRegression()
         model.fit(X_train, y_train)
-        self.explainer = RegressionExplainer(model, X_test, y_test, r2_score, 
+        self.explainer = RegressionExplainer(model, X_test, y_test, 
                                         shap='linear', 
                                         cats=[{'Gender': ['Sex_female', 'Sex_male', 'Sex_nan']}, 
                                                 'Deck', 'Embarked'],
@@ -35,7 +33,7 @@ class LinearRegressionTests(unittest.TestCase):
         self.assertEqual(len(self.explainer), self.test_len)
 
     def test_int_idx(self):
-        self.assertEqual(self.explainer.get_int_idx(self.names[0]), 0)
+        self.assertEqual(self.explainer.get_idx(self.names[0]), 0)
 
     def test_random_index(self):
         self.assertIsInstance(self.explainer.random_index(), int)
@@ -45,43 +43,37 @@ class LinearRegressionTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.preds, np.ndarray)
 
     def test_pred_percentiles(self):
-        self.assertIsInstance(self.explainer.pred_percentiles, np.ndarray)
+        self.assertIsInstance(self.explainer.pred_percentiles(), np.ndarray)
 
     def test_permutation_importances(self):
-        self.assertIsInstance(self.explainer.permutation_importances, pd.DataFrame)
-        self.assertIsInstance(self.explainer.permutation_importances_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_permutation_importances_df(), pd.DataFrame)
 
     def test_metrics(self):
         self.assertIsInstance(self.explainer.metrics(), dict)
         self.assertIsInstance(self.explainer.metrics_descriptions(), dict)
 
     def test_mean_abs_shap_df(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap_df(), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_top_interactions(self):
-        self.assertIsInstance(self.explainer.shap_top_interactions("Age"), list)
-        self.assertIsInstance(self.explainer.shap_top_interactions("Age", topx=4), list)
-        self.assertIsInstance(self.explainer.shap_top_interactions("Age", cats=True), list)
-        self.assertIsInstance(self.explainer.shap_top_interactions("Gender", cats=True), list)
+        self.assertIsInstance(self.explainer.top_shap_interactions("Age"), list)
+        self.assertIsInstance(self.explainer.top_shap_interactions("Age", topx=4), list)
 
     def test_contrib_df(self):
-        self.assertIsInstance(self.explainer.contrib_df(0), pd.DataFrame)
-        self.assertIsInstance(self.explainer.contrib_df(0, cats=False), pd.DataFrame)
-        self.assertIsInstance(self.explainer.contrib_df(0, topx=3), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_contrib_df(0), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_contrib_df(0, topx=3), pd.DataFrame)
 
     def test_shap_base_value(self):
-        self.assertIsInstance(self.explainer.shap_base_value, (np.floating, float))
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
 
     def test_shap_values_shape(self):
-        self.assertTrue(self.explainer.shap_values.shape == (len(self.explainer), len(self.explainer.columns)))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
 
     def test_shap_values(self):
-        self.assertIsInstance(self.explainer.shap_values, np.ndarray)
-        self.assertIsInstance(self.explainer.shap_values_cats, np.ndarray)
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
 
     def test_mean_abs_shap(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap, pd.DataFrame)
-        self.assertIsInstance(self.explainer.mean_abs_shap_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_calculate_properties(self):
         self.explainer.calculate_properties(include_interactions=False)
@@ -93,13 +85,6 @@ class LinearRegressionTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.pdp_df("Age", index=0), pd.DataFrame)
         self.assertIsInstance(self.explainer.pdp_df("Gender", index=0), pd.DataFrame)
 
-    def test_get_dfs(self):
-        cols_df, shap_df, contribs_df = self.explainer.get_dfs()
-        self.assertIsInstance(cols_df, pd.DataFrame)
-        self.assertIsInstance(shap_df, pd.DataFrame)
-        self.assertIsInstance(contribs_df, pd.DataFrame)
-
-
 
 class LogisticRegressionTests(unittest.TestCase):
     def setUp(self):
@@ -110,7 +95,7 @@ class LogisticRegressionTests(unittest.TestCase):
         model.fit(X_train, y_train)
 
         self.explainer = ClassifierExplainer(
-                            model, X_test, y_test, roc_auc_score, 
+                            model, X_test, y_test, 
                             shap='linear',
                             cats=['Sex', 'Deck', 'Embarked'],
                             labels=['Not survived', 'Survived'],
@@ -120,41 +105,36 @@ class LogisticRegressionTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.preds, np.ndarray)
 
     def test_pred_percentiles(self):
-        self.assertIsInstance(self.explainer.pred_percentiles, np.ndarray)
+        self.assertIsInstance(self.explainer.pred_percentiles(), np.ndarray)
 
     def test_columns_ranked_by_shap(self):
         self.assertIsInstance(self.explainer.columns_ranked_by_shap(), list)
-        self.assertIsInstance(self.explainer.columns_ranked_by_shap(cats=True), list)
 
     def test_permutation_importances(self):
-        self.assertIsInstance(self.explainer.permutation_importances, pd.DataFrame)
-        self.assertIsInstance(self.explainer.permutation_importances_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_permutation_importances_df(), pd.DataFrame)
 
     def test_metrics(self):
         self.assertIsInstance(self.explainer.metrics(), dict)
         self.assertIsInstance(self.explainer.metrics_descriptions(), dict)
 
     def test_mean_abs_shap_df(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap_df(), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_contrib_df(self):
-        self.assertIsInstance(self.explainer.contrib_df(0), pd.DataFrame)
-        self.assertIsInstance(self.explainer.contrib_df(0, cats=False), pd.DataFrame)
-        self.assertIsInstance(self.explainer.contrib_df(0, topx=3), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_contrib_df(0), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_contrib_df(0, topx=3), pd.DataFrame)
 
     def test_shap_base_value(self):
-        self.assertIsInstance(self.explainer.shap_base_value, (np.floating, float))
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
 
     def test_shap_values_shape(self):
-        self.assertTrue(self.explainer.shap_values.shape == (len(self.explainer), len(self.explainer.columns)))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
 
     def test_shap_values(self):
-        self.assertIsInstance(self.explainer.shap_values, np.ndarray)
-        self.assertIsInstance(self.explainer.shap_values_cats, np.ndarray)
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
 
     def test_mean_abs_shap(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap, pd.DataFrame)
-        self.assertIsInstance(self.explainer.mean_abs_shap_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_calculate_properties(self):
         self.explainer.calculate_properties(include_interactions=False)
@@ -174,29 +154,20 @@ class LogisticRegressionTests(unittest.TestCase):
         self.assertEqual(self.explainer.pos_label, 0)
         self.assertEqual(self.explainer.pos_label_str, "Not survived")
 
-    def test_get_prop_for_label(self):
-        self.explainer.pos_label = 1
-        tmp = self.explainer.pred_percentiles
-        self.explainer.pos_label = 0
-        self.assertTrue(np.alltrue(self.explainer.get_prop_for_label("pred_percentiles", 1)==tmp))
-
     def test_pred_probas(self):
-        self.assertIsInstance(self.explainer.pred_probas, np.ndarray)
+        self.assertIsInstance(self.explainer.pred_probas(), np.ndarray)
 
     def test_metrics(self):
         self.assertIsInstance(self.explainer.metrics(), dict)
         self.assertIsInstance(self.explainer.metrics(cutoff=0.9), dict)
 
     def test_precision_df(self):
-        self.assertIsInstance(self.explainer.precision_df(), pd.DataFrame)
-        self.assertIsInstance(self.explainer.precision_df(multiclass=True), pd.DataFrame)
-        self.assertIsInstance(self.explainer.precision_df(quantiles=4), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(multiclass=True), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(quantiles=4), pd.DataFrame)
 
     def test_lift_curve_df(self):
-        self.assertIsInstance(self.explainer.lift_curve_df(), pd.DataFrame)
-
-    def test_prediction_result_markdown(self):
-        self.assertIsInstance(self.explainer.prediction_result_markdown(0), str)
+        self.assertIsInstance(self.explainer.get_liftcurve_df(), pd.DataFrame)
 
 
 class LogisticRegressionKernelTests(unittest.TestCase):
@@ -208,19 +179,29 @@ class LogisticRegressionKernelTests(unittest.TestCase):
         model.fit(X_train, y_train)
 
         self.explainer = ClassifierExplainer(
-                            model, X_test, y_test, 
+                            model, X_test.iloc[:20], y_test.iloc[:20], 
                             shap='kernel', model_output='probability', 
                             X_background=shap.sample(X_train, 5),
                             cats=[{'Gender': ['Sex_female', 'Sex_male', 'Sex_nan']}, 
                                                 'Deck', 'Embarked'],
-                            labels=['Not survived', 'Survived'],
-                            idxs=test_names)
+                            labels=['Not survived', 'Survived'])
 
     def test_shap_values(self):
-        self.assertIsInstance(self.explainer.shap_base_value, (np.floating, float))
-        self.assertTrue(self.explainer.shap_values.shape == (len(self.explainer), len(self.explainer.columns)))
-        self.assertIsInstance(self.explainer.shap_values, np.ndarray)
-        self.assertIsInstance(self.explainer.shap_values_cats, np.ndarray)
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
 
-    
 
+class LinearRegressionKernelTests(unittest.TestCase):
+    def setUp(self):
+        X_train, y_train, X_test, y_test = titanic_fare()
+        self.test_len = len(X_test)
+
+        model = LinearRegression().fit(X_train, y_train)
+        self.explainer = RegressionExplainer(model, X_test.iloc[:20], y_test.iloc[:20], shap='kernel',
+                                                X_background=shap.sample(X_train, 5))
+
+    def test_shap_values(self):
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
